# frozen_string_literal: true

require 'active_record'
require 'binance-ruby'

require_relative 'whitelist/option_parser'
# require_relative 'whitelist/coin'
# require_relative 'whitelist/binance_account'
require_relative 'whitelist/binance_cap'
require_relative 'whitelist/version'

module Abot
  module Whitelist
    class << self
      def run
        Whitelist::OptionParser.instance do |parser|
          parser.program_name = 'abot-whitelist'
          parser.version = Abot::Whitelist::VERSION

          parser.separator ''
          parser.separator 'Application options:'

          parser.add_option(
            :list_number, '--list_number=number',
            'Порядковый номер списка',
            required: true
          )

          parser.add_option(
            :top, '--top=number',
            'Число монет (ТОП по капитализации)',
          )
        end.final!

        list_number = Whitelist::OptionParser.instance.options[:list_number].to_i
        top_number = (Whitelist::OptionParser.instance.options[:top] || 100).to_i

        raise 'list_number is wrong' unless list_number.positive?
        raise 'top is wrong' unless top_number.positive?

        base_list = Abot::Whitelist::BaseWhitelist.base_whitelist(list_number: list_number)
        BinanceCap.send_req(base_list: base_list, top_number: top_number)
      end
    end
  end
end
